# Security Policy

## Supported Versions

Use this section to tell people about which versions of your project are
currently being supported with security updates.

| Version | Supported          |
| ------- | ------------------ |
| 1.3.0   | :white_check_mark: |

## Reporting a Vulnerability

For reporting an issue, please open an [Issue](https://github.com/awinml/voyage-embedders-haystack/issues).
